MessageType

Enum MessageType 

pub enum MessageType {
    Version {
        version: [u8; 4],
    },
    Audio {
        samples_offset: usize,
        samples_len: usize,
    },
    Event {
        name_offset: usize,
        typ: EventType,
        start: u32,
        end: u32,
        name_len: usize,
    },
}
A type for interpreting buffer data, instead of taking references to the underlying data. This is for when the data is on your stack, and you want to borrow the results yourself.

Mostly, you should use Message instead.

Variants



Version

Fields

version: [u8; 4]


Audio

With this variant, you should then be able to:

Fields

samples_offset: usize

The index to the start of the data slice where the audio begins.

samples_len: usize

This length of the slice you should take in order to grab the audio frame.



Event

Fields

name_offset: usize
start: u32
end: u32
name_len: usize